@@ -45,7 +45,7 @@ mod task;
 
 use std::path::PathBuf;
 
-const CHOMP_CORE: &str = "https://ga.jspm.io/npm:@chompbuild/extensions@0.1.12/";
+const CHOMP_CORE: &str = "https://ga.jspm.io/npm:@chompbuild/extensions@0.1.14/";
 
 const CHOMP_INIT: &str = r#"version = 0.1
 
@@ -404,6 +404,7 @@ async fn main() -> Result<()> {
                     env_default: task.env_default.unwrap_or_default(),
                     env_replace: task.env_replace,
                     invalidation: task.invalidation,
+                    validation: task.validation,
                     run: task.run,
                     name: task.name,
                     serial: task.serial,
@@ -474,6 +475,7 @@ async fn main() -> Result<()> {
                                     env: HashMap::new(),
                                     env_default: HashMap::new(),
                                     invalidation: None,
+                                    validation: None,
                                     serial: None,
                                     stdio: None,
                                     template: None,
